@@ -60,4 +60,23 @@ COL_NAMES = {
     ('cell_parser_feature_count_summary', 'Unassigned_Ambiguity'): 'DELETE',
     ('cell_parser_feature_count_summary', 'Unassigned_Total'): 'UnassignedRNAReads',
     ('cell_parser_feature_count_summary', 'AssignedRNAReadsRate'): 'AssignedRNAReadsRate',
+    ('cell_parser_call_chromatin_contacts', 'cis'): 'CisContacts',
+    ('cell_parser_call_chromatin_contacts', 'ciscut'): 'CisCutContacts',
+    ('cell_parser_call_chromatin_contacts', 'cis_multi'): 'CisMultiContacts',
+    ('cell_parser_call_chromatin_contacts', 'ciscut_multi'): 'CisCutMultiContacts',
+    ('cell_parser_call_chromatin_contacts', 'trans'): 'TransContacts',
+    ('cell_parser_call_chromatin_contacts', 'transcut',): 'TransCutContacts',
+    ('cell_parser_call_chromatin_contacts', 'trans_multi'): 'TransMultiContacts',
+    ('cell_parser_call_chromatin_contacts', 'transcut_multi'): 'TransCutMultiContacts',
+    ('cell_parser_call_chromatin_contacts', 'chimeric'): 'ChimericContacts',
+    ('cell_parser_call_chromatin_contacts', 'no'): 'NoContacts',
+    ('cell_parser_call_chromatin_contacts', 'mapped_frag'): 'MappedFragments',
+    ('cell_parser_call_chromatin_contacts', 'dedup_frag'): 'DeduppedContacts',
+    ('cell_parser_call_chromatin_contacts', 'dup_rate'): 'ContactsDeduplicationRate',
+    ('cell_parser_call_chromatin_contacts', 'TotalCisContacts'): '',
+    ('cell_parser_call_chromatin_contacts', 'TotalTransContacts'): '',
+    ('cell_parser_call_chromatin_contacts', 'TotalMultiContacts'): '',
+    ('cell_parser_call_chromatin_contacts', 'CisContactsRatio'): '',
+    ('cell_parser_call_chromatin_contacts', 'TransContactsRatio'): '',
+    ('cell_parser_call_chromatin_contacts', 'MultiContactsRatio'): '',
 }
