@@ -107,7 +107,51 @@ def snmct_summary():
     all_stats = pd.concat(all_stats, axis=1)
     all_stats.index.name = 'cell'
     all_stats.to_csv(f'MappingSummary.csv.gz')
+    return all_stats
 
-    # TODO
-    # 2. aggregate feature count this can be a separate func and call in snakefile
+
+def snm3c_summary():
+    """
+    Generate snm3C pipeline MappingSummary.csv.gz and save into cwd
+
+    Returns
+    -------
+    pd.DataFrame
+    """
+    all_stats = []
+
+    # fastq trimming stats
+    df = parse_single_stats_set(f'fastq/*.trimmed.stats.txt',
+                                cell_parser_cutadapt_trim_stats)
+    all_stats.append(df)
+
+    # hisat-3n mapping PE
+    df = parse_single_stats_set(f'bam/*.hisat3n_dna_summary.txt',
+                                cell_parser_hisat_summary)
+    all_stats.append(df)
+
+    # hisat-3n mapping split-reads SE
+    df = parse_single_stats_set(f'bam/*.hisat3n_dna_split_reads_summary.txt',
+                                cell_parser_hisat_summary, prefix='SplitReads')
+    all_stats.append(df)
+
+    # uniquely mapped reads dedup
+    df = parse_single_stats_set(f'bam/*.all_reads.deduped.matrix.txt',
+                                cell_parser_picard_dedup_stat, prefix='UniqueAlign')
+    all_stats.append(df)
+
+    # call chromatin contacts
+    df = parse_single_stats_set(f'hic/*.all_reads.contact_stats.csv',
+                                cell_parser_call_chromatin_contacts)
+    all_stats.append(df)
+
+    # allc count
+    df = parse_single_stats_set(f'allc/*.allc.tsv.gz.count.csv',
+                                cell_parser_allc_count)
+    all_stats.append(df)
+
+    # concatenate all stats
+    all_stats = pd.concat(all_stats, axis=1)
+    all_stats.index.name = 'cell'
+    all_stats.to_csv(f'MappingSummary.csv.gz')
     return all_stats
